summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--libpager/mark-error.c6
-rw-r--r--libpager/pagemap.c2
-rw-r--r--libpager/pager-flush.c5
3 files changed, 8 insertions, 5 deletions
diff --git a/libpager/mark-error.c b/libpager/mark-error.c
index 8847ec62..348a7c7c 100644
--- a/libpager/mark-error.c
+++ b/libpager/mark-error.c
@@ -23,7 +23,8 @@ int _pager_page_errors[] = {KERN_SUCCESS, ENOSPC, EIO, EDQUOT};
/* Some error has happened indicating that the page cannot be written.
(Usually this is ENOSPC or EDQOUT.) On the next pagein which
requests write access, return the error to the kernel. (This is
- screwy because of the rules associated with m_o_lock_request.) */
+ screwy because of the rules associated with m_o_lock_request.)
+ Currently the only errors permitted are ENOSPC, EIO, and EDQUOT. */
void
_pager_mark_next_request_error(struct pager *pager,
vm_address_t offset,
@@ -60,7 +61,8 @@ _pager_mark_next_request_error(struct pager *pager,
/* We are returning a pager error to the kernel. Write down
in the pager what that error was so that the exception handling
routines can find out. (This is only necessary because the
- XP interface is not completely implemented in the kernel.) */
+ XP interface is not completely implemented in the kernel.)
+ Again, only ENOSPC, EIO, and EDQUOT are permitted. */
void
_pager_mark_object_error(struct pager *pager,
vm_address_t offset,
diff --git a/libpager/pagemap.c b/libpager/pagemap.c
index 355efa23..2adbcc0e 100644
--- a/libpager/pagemap.c
+++ b/libpager/pagemap.c
@@ -18,7 +18,7 @@
#include "priv.h"
#include <string.h>
-/* Grow the pagemap as necessary to deal with address OFF */
+/* Grow the pagemap of pager P as necessary to deal with address OFF */
void
_pager_pagemap_resize (struct pager *p,
vm_address_t off)
diff --git a/libpager/pager-flush.c b/libpager/pager-flush.c
index 2601c052..c774c3ab 100644
--- a/libpager/pager-flush.c
+++ b/libpager/pager-flush.c
@@ -32,8 +32,9 @@ pager_flush (struct pager *p, int wait)
}
-/* Have the kernel write back some pages of a pager; if WAIT is set,
- then wait for them to be finally written before returning. */
+/* Have the kernel write back some pages of a pager from OFFSET to
+ OFFSET+SIZE; if WAIT is set, then wait for them to be finally
+ written before returning. */
void
pager_flush_some (struct pager *p, vm_address_t offset,
vm_size_t size, int wait)